/* global tracianScreenReaderText */

/**
 * navigation.js
 *
 * Handles toggling the navigation menu for small screens.
 * Also adds a focus class to parent li's for accessibility.
 * Finally adds a class required to reveal the search in the mobile footer bar.
 */
( function() {

    /* ==================================================== */
    /* SCROLLPOST
    /* ==================================================== */
    function Scrollpost(opts, callback) {
      this.point = typeof opts == 'object' ? opts.point : opts;
      this.handler = opts.handler ? opts.handler : window;
      this.axis = (opts.axis == 'x') ? opts.axis : 'y';
      this.callback = callback;
      this.lastFired = '--';
      this.scrollOffset = 0;

      this.handler.addEventListener('scroll', this, false);
      this.handleEvent();
    }
    Scrollpost.prototype = {
      handleEvent : function (event) {
        var direction = this.getScrollOffset() > this.scrollOffset ? '++' : '--';
        this.scrollOffset = this.getScrollOffset();
        if (
            ((direction == '++' && this.scrollOffset > this.point) ||
            (direction == '--' && this.scrollOffset < this.point)) &&
            (direction != this.lastFired)
          ) {
          this.fire(direction);
        }
      },

      fire : function (direction) {
        this.lastFired = direction;
        this.callback(direction);
      },

      getScrollOffset : function () {
        if ( this.handler == window ) {
          return this.axis == 'x' ? this.handler.pageXOffset : this.handler.pageYOffset;
        } else {
          return this.axis == 'x' ? this.handler.scrollLeft : this.handler.scrollTop;
        }
      },

      destroy : function () {
        this.handler.removeEventListener('scroll', this, false);
      }
    };

	// Wait for DOM to be ready.
	document.addEventListener( 'DOMContentLoaded', function() {
		var container = document.getElementById( 'site-navigation' );
		if ( ! container ) {
			return;
		}

		var button = container.querySelector( 'button' );

		if ( ! button ) {
			return;
		}

		var menu = container.querySelector( 'ul' );

		// Hide menu toggle button if menu is empty and return early.
		if ( ! menu ) {
			button.style.display = 'none';
			return;
		}

		menu.classList.add( 'nav-menu' );

		button.addEventListener( 'click', function() {
			container.classList.toggle( 'toggled' );
		} );

		// Add dropdown toggle that displays child menu items.
		var mobile = document.getElementsByClassName( 'nav-menu' );

		if ( mobile.length > 0 ) {
			[].forEach.call( mobile[0].querySelectorAll( '.menu-item-has-children > a, .page_item_has_children > a' ), function( anchor ) {

				// Add dropdown toggle that displays child menu items
				var btn = document.createElement( 'button' );
				btn.classList.add( 'dropdown-toggle' );

				var btnSpan = document.createElement( 'span' );
				btnSpan.classList.add( 'screen-reader-text' );
				btnSpan.appendChild( document.createTextNode( tracianScreenReaderText.expand ) );

				btn.appendChild( btnSpan );

				anchor.parentNode.insertBefore( btn, anchor.nextSibling );

				// Set the active submenu dropdown toggle button initial state
				if ( anchor.parentNode.classList.contains( 'current-menu-ancestor' ) ) {
					btn.classList.add( 'toggled-on' );
					btn.nextElementSibling.classList.add( 'toggled-on' );
				}

				// Add event listener
				btn.addEventListener( 'click', function() {
					btn.classList.toggle( 'toggled-on' );

					// Remove text inside span
					while ( btnSpan.firstChild ) {
						btnSpan.removeChild( btnSpan.firstChild );
					}

					var expanded = btn.classList.contains( 'toggled-on' );

					btnSpan.appendChild( document.createTextNode( expanded ? tracianScreenReaderText.collapse : tracianScreenReaderText.expand ) );
					btn.nextElementSibling.classList.toggle( 'toggled-on' );
				} );
			} );
		}

		// Add focus class to parents of sub-menu anchors.
		[].forEach.call( document.querySelectorAll( '.site-header .menu-item > a, .site-header .page_item > a, .site-header-cart a' ), function( anchor ) {
			var li = anchor.parentNode;
			anchor.addEventListener( 'focus', function() {
				li.classList.add( 'focus' );
			} );
			anchor.addEventListener( 'blur', function() {
				li.classList.remove( 'focus' );
			} );
		} );

		// Add an identifying class to dropdowns when on a touch device
		// This is required to switch the dropdown hiding method from a negative `left` value to `display: none`.
		if ( ( 'ontouchstart' in window || navigator.maxTouchPoints ) && window.innerWidth > 767 ) {
			[].forEach.call( document.querySelectorAll( '.site-header ul ul, .site-header-cart .widget_shopping_cart' ), function( element ) {
				element.classList.add( 'sub-menu--is-touch-device' );
			} );
		}

        if ( document.body.classList.contains("gg-has-stiky-menu") ) {
            var fixedMenuTrigger = new Scrollpost(200, function(direction) {
                if (direction == '--') {
                    container.classList.remove('sticky-nav');
                } else {
                    container.classList.add('sticky-nav');
                }
            });
        }

        //Searchform
        if ( document.body.classList.contains("gg-has-search") ) {
            var search_form = document.getElementById( 'header-searchform' );
            var search_btn  = document.getElementById( 'trigger-header-search' );
            var input = search_form.querySelector( 'input#s' );
            var blured = document.getElementById( 'site-navigation' );

            search_btn.addEventListener( 'click', function(event) {
                event.preventDefault();
                input.focus();
                search_form.classList.toggle( 'toggled' );
                blured.classList.toggle( 'blur' );
            } );

            if (input.blur()) {
                search_form.classList.toggle( 'toggled' );
                blured.classList.toggle( 'blur' );
            }
        }

	} );


} )();
