<?php
/**
 * Tracian Class
 *
 * @since    2.0.0
 * @package  tracian
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

if ( ! class_exists( 'Tracian' ) ) :

    /**
     * The main Tracian class
     */
    class Tracian {

        /**
         * Setup class.
         *
         * @since 1.0
         */
        public function __construct() {
            add_action( 'after_setup_theme', array( $this, 'setup' ) );
            add_action( 'widgets_init', array( $this, 'widgets_init' ) );
            add_action( 'wp_enqueue_scripts', array( $this, 'scripts' ), 10 );
            add_action( 'wp_enqueue_scripts', array( $this, 'child_scripts' ), 30 ); // After WooCommerce.
            add_filter( 'body_class', array( $this, 'body_classes' ) );
            add_filter( 'wp_page_menu_args', array( $this, 'page_menu_args' ) );
            add_filter( 'navigation_markup_template', array( $this, 'navigation_markup_template' ) );
        }

        /**
         * Sets up theme defaults and registers support for various WordPress features.
         *
         * Note that this function is hooked into the after_setup_theme hook, which
         * runs before the init hook. The init hook is too late for some features, such
         * as indicating support for post thumbnails.
         */
        public function setup() {
            /*
             * Load Localisation files.
             *
             * Note: the first-loaded translation file overrides any following ones if the same translation is present.
             */

            // Loads wp-content/languages/themes/tracian-it_IT.mo.
            load_theme_textdomain( 'tracian', trailingslashit( WP_LANG_DIR ) . 'themes/' );

            // Loads wp-content/themes/child-theme-name/languages/it_IT.mo.
            load_theme_textdomain( 'tracian', get_stylesheet_directory() . '/languages' );

            // Loads wp-content/themes/tracian/languages/it_IT.mo.
            load_theme_textdomain( 'tracian', get_template_directory() . '/languages' );

            /**
             * Add default posts and comments RSS feed links to head.
             */
            add_theme_support( 'automatic-feed-links' );

            /*
             * Enable support for Post Thumbnails on posts and pages.
             *
             * @link https://developer.wordpress.org/reference/functions/add_theme_support/#Post_Thumbnails
             */
            add_theme_support( 'post-thumbnails' );
            set_post_thumbnail_size( 9999, 9999 );

            /**
             * Enable support for site logo.
             */
            add_theme_support(
                'custom-logo', apply_filters(
                    'tracian_custom_logo_args', array(
                        'height'      => 27,
                        'width'       => 200,
                        'flex-width'  => true,
                        'flex-height' => true,
                    )
                )
            );

            /**
             * Register menu locations.
             */
            register_nav_menus(
                apply_filters(
                    'tracian_register_nav_menus', array(
                        'main-menu'      => esc_html__('Main Menu', 'tracian'),
                        'secondary-menu' => esc_html__('Secondary Menu', 'tracian'),
                    )
                )
            );

            /*
             * Switch default core markup for search form, comment form, comments, galleries, captions and widgets
             * to output valid HTML5.
             */
            add_theme_support(
                'html5', apply_filters(
                    'tracian_html5_args', array(
                        'search-form',
                        'comment-form',
                        'comment-list',
                        'gallery',
                        'caption',
                        'widgets',
                    )
                )
            );

            /**
             * Setup the WordPress core custom background feature.
             */
            add_theme_support(
                'custom-background', apply_filters(
                    'tracian_custom_background_args', array(
                        'default-color' => apply_filters( 'tracian_default_background_color', 'ffffff' ),
                        'default-image' => '',
                    )
                )
            );

            /**
             * Setup the WordPress core custom header feature.
             */
            add_theme_support(
                'custom-header', apply_filters(
                    'tracian_custom_header_args', array(
                        'default-image' => '',
                        'header-text'   => false,
                        'width'         => 1950,
                        'height'        => 500,
                        'flex-width'    => true,
                        'flex-height'   => true,
                    )
                )
            );

            /**
             *  Add support for the Site Logo plugin and the site logo functionality in JetPack
             *  https://github.com/automattic/site-logo
             *  http://jetpack.me/
             */
            add_theme_support(
                'site-logo', apply_filters(
                    'tracian_site_logo_args', array(
                        'size' => 'full',
                    )
                )
            );

            /**
             * Declare support for title theme feature.
             */
            add_theme_support( 'title-tag' );

            /**
             * Declare support for selective refreshing of widgets.
             */
            add_theme_support( 'customize-selective-refresh-widgets' );
        }

        /**
         * Register widget area.
         *
         * @link https://codex.wordpress.org/Function_Reference/register_sidebar
         */
        public function widgets_init() {

            //Construct the default sidebars array
            $sidebars_array = array(
                esc_html__('Page Sidebar', 'tracian')          => 'sidebar-page',
                esc_html__('Posts Sidebar', 'tracian')         => 'sidebar-posts',
                esc_html__('Search Sidebar', 'tracian')        => 'sidebar-search',
                esc_html__('Shop Sidebar', 'tracian')          => 'sidebar-shop',
                esc_html__('Product Sidebar', 'tracian')       => 'sidebar-product',
                esc_html__('Footer First Sidebar', 'tracian')  => 'sidebar-footer-first',
                esc_html__('Footer Second Sidebar', 'tracian') => 'sidebar-footer-second',
                esc_html__('Footer Third Sidebar', 'tracian')  => 'sidebar-footer-third',
            );


            foreach ($sidebars_array as $sidebar_name => $sidebar_id) {
                register_sidebar(
                    array(
                        'name'          => $sidebar_name,
                        'id'            => $sidebar_id,
                        'before_widget' => '<div id="%1$s" class="gg-widget %2$s">',
                        'after_widget'  => '</div>',
                        'before_title'  => '<h4 class="widget-title">',
                        'after_title'   => '</h4>'
                    )
                );
            }
            

            //Dynamic sidebars
            if ( class_exists( 'acf' ) ) { //Check to see if ACF is installed
                if (_get_field('gg_sidebars','option')) {
                    while (_has_sub_field('gg_sidebars','option')) { //Loop through sidebar fields to generate custom sidebars

                        $s_name = _get_sub_field('gg_sidebar_name','option');
                        $s_id   = str_replace(" ", "-", $s_name); // Replaces spaces in Sidebar Name to dash
                        $s_id   = strtolower($s_id); // Transforms edited Sidebar Name to lowercase
                        
                        register_sidebar( array(
                            'name'          => $s_name,
                            'id'            => $s_id,
                            'before_widget' => '<div id="%1$s" class="gg-widget %2$s">',
                            'after_widget'  => '</div>',
                            'before_title'  => '<h4 class="widget-title">',
                            'after_title'   => '</h4>',
                        ) );
                    }
                }
            }

            
        }

        /**
         * Enqueue scripts and styles.
         *
         * @since  1.0.0
         */
        public function scripts() {

            /**
             * Styles
             */          
            if ( tracian_is_wpml_activated() ) {
                // get lang direction and enqueue rtl stylesheet if needed.
                if( ICL_LANGUAGE_CODE == 'he' ){
                    wp_enqueue_style('rtl', get_template_directory_uri().'/rtl.css');
                }
            }

            wp_enqueue_style( 'tracian-style', get_template_directory_uri() . '/style.css', '', TRACIAN_THEMEVERSION );
            if ( class_exists( 'acf' ) ) {
                wp_add_inline_style( 'tracian-style', tracian_generate_dynamic_css() );
            }

            /**
             * Fonts
             */
            $google_fonts = apply_filters(
                'tracian_google_font_families', array(
                    'arapey' => 'Arapey:400,400i',
                    'old-standard-tt' => 'Old+Standard+TT:400,400i,700',
                )
            );

            $query_args = array(
                'family' => implode( '|', $google_fonts ),
                'subset' => urlencode( 'latin,latin-ext' ),
            );

            $fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );

            if ( ! class_exists( 'acf' ) ) {
                wp_enqueue_style( 'tracian-fonts', $fonts_url, array(), null );
            }

            /**
             * Scripts
             */
            wp_enqueue_script( 'tracian-navigation', get_template_directory_uri() . '/assets/js/navigation.js', array(), TRACIAN_THEMEVERSION, true );
            wp_enqueue_script( 'tracian-skip-link-focus-fix', get_template_directory_uri() . '/assets/js/skip-link-focus-fix.js', array(), '20130115', true );

                $tracian_l10n = array(
                    'expand'   => esc_html__( 'Expand child menu', 'tracian' ),
                    'collapse' => esc_html__( 'Collapse child menu', 'tracian' ),
                );

                wp_localize_script( 'tracian-navigation', 'tracianScreenReaderText', $tracian_l10n );

            /*Plugins*/
            wp_enqueue_script('imagesloaded', get_template_directory_uri() . '/assets/js/imagesloaded.pkgd.min.js', array('jquery'), TRACIAN_THEMEVERSION, true);
            wp_enqueue_script('countto', get_template_directory_uri() . '/assets/js/countto.js', array('jquery'), TRACIAN_THEMEVERSION, true);
            wp_enqueue_script('isotope-tracian', get_template_directory_uri() . '/assets/js/isotope.pkgd.min.js', array('jquery'), TRACIAN_THEMEVERSION, true);
            wp_enqueue_script('slick', get_template_directory_uri() . '/assets/js/slick.min.js', array('jquery'), TRACIAN_THEMEVERSION, true);
            wp_enqueue_script('swiper', get_template_directory_uri() . '/assets/js/swiper.min.js', array('jquery'), TRACIAN_THEMEVERSION, true);
            wp_enqueue_script('waypoints', get_template_directory_uri() . '/assets/js/jquery.waypoints.min.js', array('jquery'), TRACIAN_THEMEVERSION, true);
            
            /* General */
            wp_enqueue_script('tracian-custom', get_template_directory_uri() . '/assets/js/custom.js', array('jquery'), TRACIAN_THEMEVERSION, true);


            if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
                wp_enqueue_script( 'comment-reply' );
            }

            /* Custom scripts from theme options Custom Scripts tab */
            $custom_scripts ='';
            if (_get_field('gg_script', 'option') != '') :
                $custom_scripts = stripslashes(_get_field('gg_script', 'option'));
            endif; 
            wp_add_inline_script( 'tracian-custom-js', $custom_scripts );
        }

        /**
         * Enqueue child theme stylesheet.
         * A separate function is required as the child theme css needs to be enqueued _after_ the parent theme
         * primary css and the separate WooCommerce css.
         *
         * @since  1.5.3
         */
        public function child_scripts() {
            if ( is_child_theme() ) {
                $child_theme = wp_get_theme( get_stylesheet() );
                wp_enqueue_style( 'tracian-child-style', get_stylesheet_uri(), array(), $child_theme->get( 'Version' ) );
            }
        }

        /**
         * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
         *
         * @param array $args Configuration arguments.
         * @return array
         */
        public function page_menu_args( $args ) {
            $args['show_home'] = true;
            return $args;
        }

        /**
         * Adds custom classes to the array of body classes.
         *
         * @param array $classes Classes for the body element.
         * @return array
         */
        public function body_classes( $classes ) {
            global $post;

            //Page layout
            $page_container_style           = _get_field('gg_page_layout_container',tracian_global_page_id(), false);

            $page_subheader_style           = _get_field('gg_page_header_style',tracian_global_page_id(), 'style1');
            $page_subheader_align           = _get_field('gg_page_header_alignment',tracian_global_page_id(), 'center');
            $page_subheader_slider          = _get_field('gg_page_header_slider', tracian_global_page_id(), false);
            $page_subheader_slider_position = _get_field('gg_page_header_slider_position', tracian_global_page_id(),'under_header');

            if ( $page_container_style && !is_archive() && !is_search() ) {
                $classes[] = 'gg-page-container-780';
            }

            if ( has_post_thumbnail( tracian_global_page_id() ) ) {
                $classes[] = 'gg-page-has-header-image';
            }
            if ( $page_subheader_slider ) {
                $classes[] = 'gg-page-has-header-slider';
            }
            if ( $page_subheader_slider_position ) {
                $classes[] = 'gg-slider-is-'.$page_subheader_slider_position.'';
            }

            if ( $page_subheader_style ) {
                if (is_search()) {
                    $classes[] = 'gg-page-subheader-style1';
                } else {
                    $classes[] = 'gg-page-subheader-'.$page_subheader_style.''; 
                }
            }
            if ( $page_subheader_align ) {
                $classes[] = 'gg-page-subheader-'.$page_subheader_align.'-align';
            }



            //Header styles
            $nav_sticky   = _get_field('gg_sticky_menu','option', false);
            
            if ($nav_sticky) {
                $classes[] = 'gg-has-stiky-menu';
            }

            if ( HEADER_STYLE ) {
                $classes[] = 'gg-'.HEADER_STYLE.'-header';
            }
            if ( HEADER_SEARCH === true ) {
                $classes[] = 'gg-has-search';
            }
            
            //End header styles

            if ( FOOTER_STYLE ) {
                $classes[] = 'gg-footer-'.FOOTER_STYLE;
            }

            if (!is_multi_author()) {
                $classes[] = 'single-author';
            }


            //WPML
            if ( tracian_is_wpml_activated() ) {
                
                $classes[] = 'gg-theme-has-wpml';
                
                //WPML currency
                if ( class_exists('woocommerce_wpml') ) {
                    $classes[] = 'gg-theme-has-wpml-currency';
                }
            }

            //Add class if VisualComposer is active on page
            if ( isset($post->post_content) && false !== stripos($post->post_content, '[vc_row') ) {
                $classes[] = 'wpb-is-on';
            }

            // Add class if sidebar is used.
            if ( ! is_active_sidebar( 'sidebar-page' ) && ( is_page() || is_home() ) ) {
                $classes[] = 'no-active-sidebar-page';
            } 

            if ( ! is_active_sidebar( 'sidebar-posts' ) && is_single() ) {
                $classes[] = 'no-active-sidebar-post';
            }

            return $classes;
        }

        /**
         * Custom navigation markup template hooked into `navigation_markup_template` filter hook.
         */
        public function navigation_markup_template() {
            $template  = '<nav id="post-navigation" class="navigation %1$s" role="navigation" aria-label="' . esc_html__( 'Post Navigation', 'tracian' ) . '">';
            $template .= '<h2 class="screen-reader-text">%2$s</h2>';
            $template .= '<div class="nav-links">%3$s</div>';
            $template .= '</nav>';

            return apply_filters( 'tracian_navigation_markup_template', $template );
        }

        
    }
endif;

return new Tracian();